@@ -62,6 +62,10 @@ class PyCytoData():
         with the number of rows of the expression matrix.
     :raises exceptions.DimensionMismatchError: The number of sample indices does not agree
         with the number of rows of the expression matrix.
+        
+    :Additional Attributes:
+    
+    - **reductions**: A ``reductions`` object for dimension reduction using ``CytofDR``.
     """
     
     def __init__(self,
@@ -109,6 +113,12 @@ class PyCytoData():
         if self._lineage_channels is not None and not np.all(np.isin(self._lineage_channels, self._channels)):
             raise ValueError("Some lineage channels are not listed in channel names.")
         
+        self._lineage_channels_indices: np.ndarray
+        if lineage_channels is None:
+            self._lineage_channels_indices = np.arange(self.n_channels)
+        else:
+            self._lineage_channels_indices = np.where(np.isin(lineage_channels, self.channels))
+        
         self._reductions: Optional[dr.Reductions] = None
     
     
@@ -164,7 +174,7 @@ class PyCytoData():
                    cor_channels: Optional[ArrayLike]=None,
                    dead_channel: Optional[ArrayLike]=None,
                    DNA_channels: Optional[ArrayLike]=None,
-                   cofactor: int=2,
+                   cofactor: int=5,
                    cutoff_DNA_sd: float=2,
                    dead_cutoff_quantile: float=0.03,
                    cor_cutoff_quantile: float=0.03,
@@ -180,7 +190,6 @@ class PyCytoData():
         4. Gate for live cells.
         5. Gate for anomalies using center, offset, and residual channels. 
 
-        :param data: The expression matrix array of two dimensions.
         :param gate_debris_removal: Whether to gate to remove debris, defaults to True.
         :type gate_debris_removal: bool
         :param gate_intact_cells: Whether to gate for intact cells, defaults to True.
@@ -205,6 +214,8 @@ class PyCytoData():
         :type dead_channel: ArrayLike, optional
         :param DNA_channels: The DNA channels as specify by name, defaults to None
         :type DNA_channels: ArrayLike, optional
+        :param cofactor: The cofactor for arcsinh transforatrion, default to 5.
+        :type cofactor: int, optional
         :param cutoff_DNA_sd: The standard deviation cutoff for DNA channels. Here, we
             specifically measure how many standard deviations away from the mean, defaults to 2
         :type cutoff_DNA_sd: float
@@ -322,10 +333,9 @@ class PyCytoData():
         if not OPT_PCK["CytofDR"]:
             raise ImportError("`CytofDR` is not installed. Please install `CytofDR` first.")
         
-        self.reductions = dr.run_dr_methods(data=self.expression_matrix, methods=methods, out_dims=out_dims,
+        self.reductions = dr.run_dr_methods(data=self.expression_matrix[:,self._lineage_channels_indices], methods=methods, out_dims=out_dims,
                                             n_jobs=n_jobs, verbose=verbose, suppress_error_msg=suppress_error_msg)
         
-        self.reductions.add_evaluation_metadata(original_data=self.expression_matrix)
         if np.any(self.cell_types != None):
             self.reductions.add_evaluation_metadata(original_cell_types=self.cell_types)
             
@@ -361,7 +371,7 @@ class PyCytoData():
         :return: A new PyCytoData after subsetting
         :rtype: PyCytoData, optional
         
-        :raises ValueErro: Filtering out all cells with nothing in the expression matrix, which is unsupported.
+        :raises ValueError: Filtering out all cells with nothing in the expression matrix, which is unsupported.
         """
         if sample is None and cell_types is None and channels is None:
             raise TypeError("'channels', 'sample', and 'cell_types' cannot all be None.")
@@ -434,7 +444,7 @@ class PyCytoData():
         return self.expression_matrix[:, channel_indices], self.channels[channel_indices]
         
         
-    def __len__(self):
+    def __len__(self) -> int:
         """The length of the PyCytoData Class.
 
         This method implements the ``len`` of the builtin
@@ -475,7 +485,7 @@ class PyCytoData():
         return out_str
     
     
-    def __getitem__(self, items: Union[slice, List[int], np.ndarray, Tuple[Union[slice, List[int], np.ndarray], Union[slice, List[int], np.ndarray]]]):
+    def __getitem__(self, items: Union[slice, List[int], np.ndarray, Tuple[Union[slice, List[int], np.ndarray], Union[slice, List[int], np.ndarray]]]) -> PyCytoData:
         """The method to index elements of the PyCytoData object.
 
         This method implements the bracket notation to index part of the class.
@@ -733,7 +743,7 @@ class PyCytoData():
     def lineage_channels(self) -> Optional[np.ndarray]:
         """Getter for lineage_channels.
 
-        :return: An array of lineage channels or None.
+        :return: An array of lineage channels or ``None``.
         :rtype: np.ndarray, optional
         """
         return self._lineage_channels
@@ -754,17 +764,34 @@ class PyCytoData():
         
     @property
     def reductions(self) -> Optional[dr.Reductions]:
+        """Getter for reductions.
+
+        :return: A ``Reductions`` object or ``None``.
+        :rtype: CytofDR.dr.Reductions, optional
+        """
         return self._reductions
     
     
     @reductions.setter
     def reductions(self, reductions: Optional[dr.Reductions]):
+        """Set reductions.
+
+        :param reductions: A ``Reductions`` object from the ``CytofDR`` package.
+        :type reductions: int
+        :raises TypeError: The object is not a ``Reductions`` object.
+        """
         if not isinstance(reductions, dr.Reductions) and reductions is not None:
             raise TypeError("'reductions' has to of type 'CytofDR.dr.Reductions' or None")
         self._reductions = reductions
 
 
 class DataLoader():
+    """The class with utility functions to load datasets.
+
+    This class offers one public utility function to load datasets, ``load_dataset``,
+    which loads and preprocesses existing benchmark datasets. All other methods are
+    private methods. Instantiation is not necessary.
+    """
 
     # Package data directory and Path
     _data_dir = pkg_resources.resource_filename("PyCytoData", "data/")
@@ -777,7 +804,7 @@ class DataLoader():
         _data_status[d] = os.path.exists(_data_path[d])
 
     @classmethod    
-    def load_dataset(cls, dataset: str, sample: Optional[ArrayLike]=None, force_download: bool = False) -> PyCytoData:
+    def load_dataset(cls, dataset: str, sample: Optional[ArrayLike]=None, force_download: bool = False, preprocess: bool=False) -> PyCytoData:
         """Load benchmark datasets.
 
         This methods downloads and load benchmark datasets. The dataset is downloaded only once, which is then
@@ -800,6 +827,10 @@ class DataLoader():
         :type sample: ArrayLike, optional
         :param force_download: Whether to download dataset regardless of previous cache, defaults to False
         :type force_download: bool
+        :param preprocess: Whether to automatically perform all the necessary preocessing, defaults to false. 
+            In the case of the existing three datasets, preprocessing includes just arcsinh transformation
+            with cofactor of 5.
+        :type preprocess: bool, optional
         :return: The loaded dataset.
         :rtype: PyCytoData
         """
@@ -841,6 +872,14 @@ class DataLoader():
             data.cell_types = metadata[:,0].flatten()
             data.sample_index = metadata[:,1].flatten()
             
+        if dataset == "levine32":
+            data.lineage_channels = data.channels[4:36]
+        if dataset == "samusik":
+            data.lineage_channels = data.channels[8:47]
+            
+        if preprocess:
+            data.preprocess(arcsinh=True, verbose=False)
+            
         return data
             
 
@@ -1009,6 +1048,21 @@ class DataLoader():
 
 
 class FileIO():
+    """A utility class to handle common IO workflows for CyTOF data.
+
+    This class includes a few utility static methods to load and save
+    CyTOF data. Currently, it includes the following methods:
+    
+    - load_delim
+    - load_expression
+    - save_2d_list_to_csv
+    - save_np_array
+    
+    Most of the methods are wrappers, but we offer a few advantages, such
+    as returning ``PyCytoData`` data and saving ``numpy`` array along
+    with channel names. For detailed documentations, read the docstring
+    for each method.
+    """
     
     @staticmethod
     def load_delim(files: Union[List[str], str],
@@ -1089,7 +1143,7 @@ class FileIO():
         :type files: Union[List[str], str]
         :param col_names: Whether the first row is channel names, default to False.
         :type col_names: bool, optional
-        :param drop_colums: The columns indices for those that need to be dropped, defaults to None.
+        :param drop_columns: The columns indices for those that need to be dropped, defaults to None.
         :type drop_columns: Union[int, List[int]], optional.
         :param delim: The delimiter to use, defaults to ``\\t``
         :type delim: str, optional.
@@ -1134,7 +1188,7 @@ class FileIO():
         :param path: Path to save the CSV file
         :type path: str
         
-        ..note:: 
+        .. note:: 
         
             By default, this method does not overwrite existing files. In case a file exists,
             a ``FileExistsError`` is thrown.
@@ -1183,38 +1237,4 @@ class FileIO():
             if col_names is not None:
                 f.write("\t".join(list(map(str, col_names))))
                 f.write("\n")
-            np.savetxt(f, array, delimiter="\t", fmt=dtype)
-            
-    
-    @staticmethod
-    def make_dir(dir_path: str, add_number_if_dir_exists: bool = False, _counter: int=0) -> str:
-        """Create a new directory
-
-        :param dir_path: Path to the new directory to be created
-        :type dir_path: str
-        :param add_number_if_dir_exists: If the directory already exists, append a number to the
-            name until creation of directory is successful, defaults to True
-        :type add_number_if_dir_exists: bool, optional
-        :return: The path to the new directory
-        :rtype: str
-        
-        .. Warning:: 
-        
-            The ``add_number_if_dir_exists`` can be dangerous when this method is run inside
-            of a loop. This behavior may be deprecated and removed in the future.
-        """
-        dir_path = dir_path.rstrip("/")
-        if _counter==0:
-            new_dir_path = dir_path
-        else:
-            new_dir_path = dir_path + str(_counter)
-        
-        try:
-            os.makedirs(new_dir_path)
-        except FileExistsError:
-            if add_number_if_dir_exists: 
-                new_dir_path = FileIO.make_dir(dir_path, _counter = _counter+1)
-            else:
-                raise
-            
-        return new_dir_path
\ No newline at end of file
+            np.savetxt(f, array, delimiter="\t", fmt=dtype)
\ No newline at end of file
